kombu.transport.pyredis — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.transport.pyredis

Redis transport.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

- Transport
- Channel

## Transport

class `kombu.transport.pyredis.` `Transport`(*args, **kwargs)
  class `Channel`(*args, **kwargs)
    `active_queues`
    `basic_cancel`(consumer_tag)
    `basic_consume`(queue, *args, **kwargs)
    `client`
    `close`()
    `get_table`(exchange)
    `subclient`

## Channel

class `kombu.transport.pyredis.` `Channel`(*args, **kwargs)
  `active_queues`
  `basic_cancel`(consumer_tag)
  `basic_consume`(queue, *args, **kwargs)
  `client`
  `close`()
  `get_table`(exchange)
  `subclient`

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »